Discover Packages
github.com/cryptopay-dev/gemstone
registry
package
Version:
v0.0.0-...-19d66a1
Opens a new window with list of versions in this module.
Published: Dec 11, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Service struct {
ID string `json:"id"`
Name string `json:"name"`
Version string `json:"version"`
Port int `json:"port"`
Addr string `json:"addr"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.